import 'dart:typed_data';

import 'package:increment/increment.dart';
import 'package:test/test.dart';

void main() {
  test('increment', () {
    final Increment increment = Increment();

    expect(increment.next, equals(0));
    expect(increment.next, equals(1));
  });

  test('max', (){
    const int limit = 10;

    final Increment increment = Increment(max: limit);

    for(int i=0; i<=limit; i++)
      expect(increment.next, equals(i));
    expect(increment.next, equals(0));


    for(int i=1; i<=limit; i++)
      expect(increment.next, equals(i));

    increment.max = limit~/2;

    expect(increment.value, 0);
  });


  test("32bit limit", (){
    const int _32bitMax = 0x7fffffff;
    final Increment increment = Increment();
    increment.value = _32bitMax - 1;

    final int incrementCurrentValue = increment.next;
    expect(incrementCurrentValue, _32bitMax);
    final Uint8List encodedLimit = Uint8List(4)..buffer.asByteData().setInt32(0, incrementCurrentValue);
    expect(encodedLimit.buffer.asByteData().getInt32(0), 0x7fffffff);

    final int incrementNextValue = increment.next;
    expect(incrementNextValue, isNot(_32bitMax+1));
    final Uint8List encodedMax = Uint8List(4)..buffer.asByteData().setInt32(0, incrementNextValue);
    expect(encodedMax.buffer.asByteData().getInt32(0), isNot(anyOf(0x7fffffff, 0x80000000)));
  });
}